import random

def generate_chord(key):
    if key == 'major':
        scale = ['C', 'D', 'E', 'F', 'G', 'A', 'B']
    elif key == 'minor':
        scale = ['A', 'B', 'C', 'D', 'E', 'F', 'G']
    else:
        print("Invalid key type. Please choose 'major' or 'minor'.")
        return None

    root_note = random.choice(scale)
    chord_type = random.choice(['major', 'minor'])  # Randomly choose between major and minor
    if chord_type == 'major':
        chord = [root_note, scale[(scale.index(root_note) + 2) % 7], scale[(scale.index(root_note) + 4) % 7]]
    elif chord_type == 'minor':
        chord = [root_note, scale[(scale.index(root_note) + 3) % 7], scale[(scale.index(root_note) + 5) % 7]]

    return chord, chord_type

def generate_melody(chord, time_signature):
    num_notes = random.randint(3, 8)  # Randomly choose between 3 and 8 notes in the melody
    melody = []

    for _ in range(num_notes):
        # Ensure that a melody note cannot repeat more than twice in a row
        last_note = melody[-1] if melody else None
        second_last_note = melody[-2] if len(melody) > 1 else None

        available_notes = [note for note in chord if note != last_note or melody.count(note) < 2]
        selected_note = random.choice(available_notes)
        melody.append(selected_note)
    
    # Randomly choose the duration in bars (1, 2, 3, or 4 bars)
    duration_bars = random.choice([1, 2, 3, 4])

    return melody, num_notes, duration_bars, time_signature

def main():
    key = input("Enter the key (major or minor): ").lower()
    chord, chord_type = generate_chord(key)

    if chord:
        time_signature = input("Enter the time signature (3/4, 4/4, or 5/4): ")
        if time_signature not in ['3/4', '4/4', '5/4']:
            print("Invalid time signature. Please choose 3/4, 4/4, or 5/4.")
            return

        melody, num_notes, duration_bars, _ = generate_melody(chord, time_signature)

        print(f"Chord: {chord}")
        print(f"Chord Type: {chord_type}")
        print(f"Melody Notes: {melody}")
        print(f"Number of Melody Notes: {num_notes}")
        print(f"Duration in Bars: {duration_bars}")
        print(f"Time Signature: {time_signature}")

if __name__ == "__main__":
    main()
